import bisect
import sys
import time
import Dibase

class CSFASTA_Parser:
    def __init__(self, fn=None, skip=True):
        self.skip_hitless_beads = skip
        if fn:
            self.open(fn)

    def open(self, fn):
        self.filename = fn
        self.file = open(fn)

    def _parse_hits(self, hit_strings):
        hits = []
        for hit in hit_strings:
            if '_' in hit:
                chr, other = hit.split('_')
            else:
                chr = ''
                other = hit
            if '.' in hit:
                loci, mm = other.split('.')
                mm = int(mm)
            else:
                loci = hit
                mm = -1
            if loci[0] == '-':
                strand = '-'
                loci = loci[1:]
            else:
                strand = '+'
            loci = int(loci)
            hits.append((chr, strand, loci, mm))
        return hits

    def parse(self):
        while True:
            line = self.file.readline().strip()
            if not line:
                return None
            if line[0] != '>':
                continue
            info = line[1:].split(',')
            if self.skip_hitless_beads and len(info) == 1:
                # skip the sequence
                self.file.readline()
                continue
            bead = info[0]
            hits = self._parse_hits(info[1:])
            seq = self.file.readline().strip()
            break
        return (bead, hits, seq)
    
    def __iter__(self):
        return self

    def next(self):
        ret = self.parse()
        if not ret:
            raise StopIteration
        return ret
        

def Convert_to_ELAND(info):
    assert len(info[1]) == 1
    hit = info[1][0]
    ELAND = []
    # name of bead
    ELAND.append(info[0])
    # sequence
    ELAND.append(Dibase.decodeSequence(info[2]))
    # match code
    mm = hit[3]
    ELAND.append('U%d' % mm)
    # error counters
    ELAND += ['.', '.', '.']
    # genome file
    chr = hit[0]
    ELAND.append('chr%s' % chr)
    # position
    ELAND.append(hit[2])
    # strand
    strand = hit[1]
    if strand == '+':
        ELAND.append('F')
    else:
        ELAND.append('R')
    # how many chars were interpreted
    ELAND.append('.')
    # positon and type of sub error
    ELAND.append('.')
    ELAND.append('.')
    print str.join('\t', map(str, ELAND))

if(len(sys.argv) < 1):
    print "Usage: %s </path/to/csfasta>"
    sys.exit(0)

csfasta = sys.argv[1]
parser = CSFASTA_Parser(csfasta)

for info in parser:
    Convert_to_ELAND(info)
